@@ -202,7 +202,11 @@ sub _update_name {
     return unless (@_ > 2); 
     my ( $self, $name, $old_name ) = @_;
     return if ($name eq $old_name);
-    my $resp = $self->service->get(RENAME_PATH, oldname => $old_name, newname => $name);
+    my $uri = $self->service->build_uri($self->service_root . RENAME_PATH,
+        oldname => $old_name,
+        newname => $name,
+    );
+    my $resp = $self->service->get($uri);
     my $new_list = $self->factory->parse_upload_response($resp);
     $self->clear_query;
 }; 
@@ -505,7 +509,7 @@ sub overload_appending {
     $self->append($other);
 }
 
-=head2 enrichment(widget => $name, [maxp => $val, correction => $algorithm, filter => $filter])
+=head2 enrichment(widget => $name, [population => $background, maxp => $val, correction => $algorithm, filter => $filter])
 
 Receive results from an enrichment widget.
 
@@ -629,7 +633,7 @@ sub append {
             my $uri = $self->service->build_uri($_->get_list_append_uri,
                 listName => $name, path => $path, $_->get_list_request_parameters,
             );
-            $resp = $self->service->agent->get($uri);
+            $resp = $self->service->get($uri);
         },
         sub {
             my $uri = $self->service->build_uri($self->service_root . LIST_APPEND_PATH, name => $name);
